<?php
/**
 * EventFactory returns concrete MythEvents to attach to MythTV recordings.
 *
 * EventFactory implements the abstract factory design pattern and returns
 * concrete MythEvents to attach to MythTV recordings.
 *
 * @version $Id: EventFactory.php,v 1.9 2006/09/22 15:18:07 dbattams Exp $
 * @author Derek Battams <derek@battams.ca>
 * @package MRE
 * @copyright 2006 GPL v2
 */

/**#@+
 * Required include
 */
require_once(APP_ROOT . '/class/SysConf.php');
require_once(APP_ROOT . '/class/DummyEvent.php');
require_once(APP_ROOT . '/class/NBAEvent.php');
require_once(APP_ROOT . '/class/NHLEvent.php');
require_once(APP_ROOT . '/class/MLBEvent.php');
require_once(APP_ROOT . '/class/NFLEvent.php');
require_once(APP_ROOT . '/class/NCAAFEvent.php');
/**#@-*/

/**
 * Returns concrete MythEvent objects to attach to MythTV recordings.
 *
 * Implementation of the abstract factory design pattern that returns
 * concrete MythEvent objects to attach to MythTV recordings.
 *
 * @package MRE
 */
class EventFactory
{
   /**
    * Static method used to request a concrete subclass.
    *
    * @param array A hash describing the MythTV recording
    * @return mixed A concrete subclass of MythEvent or NULL
    */
   static public function getEvent($data)
   {
      if(!SysConf::getInstance()->getOpt('test'))
         switch($data['title'])
         {
            case 'NBA Basketball':
               $obj = new NBAEvent($data['subtitle']); break;
            case 'NHL Hockey':
               $obj = new NHLEvent($data['subtitle']); break;
            case 'MLB Baseball':
               $obj = new MLBEvent($data['subtitle']); break;
            case 'NFL Football':
               $obj = new NFLEvent($data['subtitle']); break;
            case 'College Football':
               $obj = new NCAAFEvent($data['subtitle']); break;
            default:
               $obj = NULL;
         }
      else
         $obj = new DummyEvent();
      return $obj;
   }

   /**
    * Class constructor.
    *
    * Explicitly defined to ensure that this class can't be instantiated.
    */
   private function __construct()
   {
      return;
   }
}

?>
